@@ -945,9 +945,10 @@ class ScmCube:  # pylint:disable=too-many-public-methods
                 + ["{}: {}".format(k, v) for k, v in source_meta.items()]
             )
 
-        scmcube.cube.attributes[
-            "crunch_netcdf_scm_version"
-        ] = "{} (more info at gitlab.com/netcdf-scm/netcdf-scm)".format(__version__)
+        scmcube.cube.attributes["crunch_netcdf_scm_version"] = (
+            "{} (see Nicholls et al. (2021, https://doi.org/10.1002/gdj3.113), "
+            "more info at gitlab.com/netcdf-scm/netcdf-scm)".format(__version__)
+        )
         scmcube.cube.attributes["crunch_source_files"] = source_file_info
 
         weight_kwargs_to_save = {
